src/hotspot/share/prims/jvmtiRedefineClasses.cpp
changeset 58358 d658f4379c63
parent 57566 ad84ae073248
child 58479 35ce0ad5870a
--- a/src/hotspot/share/prims/jvmtiRedefineClasses.cpp	Thu Sep 26 14:04:25 2019 +0200
+++ b/src/hotspot/share/prims/jvmtiRedefineClasses.cpp	Thu Sep 26 09:22:49 2019 -0400
@@ -232,9 +232,9 @@
     ResolvedMethodTable::adjust_method_entries(&trace_name_printed);
   }
 
   // Set flag indicating that some invariants are no longer true.
   // See jvmtiExport.hpp for detailed explanation.
-  JvmtiExport::set_has_redefined_a_class();
+  JvmtiExport::increment_redefinition_count();
 
   // check_class() is optionally called for product bits, but is
   // always called for non-product bits.
@@ -232,9 +232,9 @@
   }
 
-  // Set flag indicating that some invariants are no longer true.
+  // Increment flag indicating that some invariants are no longer true.
   // See jvmtiExport.hpp for detailed explanation.